import { Component, Input, ViewChild, NgModule } from '@angular/core';
import { Chart } from 'chart.js';
import randomColor from 'randomcolor';
import 'rxjs';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { MatIconRegistry, MatIconModule } from '@angular/material';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChartJsComponent = /** @class */ (function () {
    function ChartJsComponent(iconRegistry, sanitizer) {
        this.iconRegistry = iconRegistry;
        this.sanitizer = sanitizer;
        this.chartData = [];
        this.chart = null;
        this.registerIcons();
    }
    Object.defineProperty(ChartJsComponent.prototype, "data", {
        set: /**
         * @param {?} value
         * @return {?}
         */
        function (value) {
            this.chartData = value;
            if (!this.ctx) {
                this.initChart();
            }
            this.updateData();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.updateChart.subscribe((/**
         * @return {?}
         */
        function () {
            _this.updateData();
        }));
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.initChart = /**
     * @return {?}
     */
    function () {
        this.ctx = this.canvasRef.nativeElement.getContext('2d');
        switch (this.type) {
            case 'chart.pie': {
                this.createChartPie();
                break;
            }
            case 'chart.bar': {
                this.createChartBar();
                break;
            }
            case 'chart.column': {
                this.createChartColumn();
                break;
            }
            default: {
                console.warn('Chart couldn\'t be generated');
                break;
            }
        }
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.createChartPie = /**
     * @return {?}
     */
    function () {
        this.chart = new Chart(this.ctx, {
            type: 'pie',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.createChartBar = /**
     * @return {?}
     */
    function () {
        this.chart = new Chart(this.ctx, {
            type: 'horizontalBar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.createChartColumn = /**
     * @return {?}
     */
    function () {
        this.chart = new Chart(this.ctx, {
            type: 'bar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.dynamicColors = /**
     * @return {?}
     */
    function () {
        /** @type {?} */
        var color = randomColor({
            count: this.chartData.data.length + 1,
            format: 'rgb',
            luminosity: 'light',
            hue: 'random',
        });
        return color;
    };
    /**
     * @return {?}
     */
    ChartJsComponent.prototype.updateData = /**
     * @return {?}
     */
    function () {
        if (this.chart) {
            this.chart.data.labels = this.chartData.labels ? this.chartData.labels : [];
            this.chart.data.datasets = [{
                    label: this.chartData.series ? this.chartData.series : null,
                    data: this.chartData.data ? this.chartData.data : [],
                    backgroundColor: this.dynamicColors(),
                }];
            this.chart.update();
        }
    };
    /**
     * @private
     * @return {?}
     */
    ChartJsComponent.prototype.registerIcons = /**
     * @private
     * @return {?}
     */
    function () {
        this.iconRegistry.addSvgIcon('bar_chart', this.sanitizer.bypassSecurityTrustResourceUrl('assets/chart-js-module/icons/baseline-bar_chart-24px.svg'));
    };
    ChartJsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'chartjs-chart',
                    template: "<div class=\"chart-container\">\n  <canvas #canvas>{{chart}}</canvas>\n</div>\n",
                    styles: [".chart-container{max-width:100%!important;overflow-y:auto}.chart-container canvas{max-height:100%;max-width:100%}.chart-container .no-data{position:absolute;top:0;width:100%;text-align:center;margin-top:32px}.chart-container .no-data mat-icon,.chart-container .no-data span{display:block;margin:auto}"]
                }] }
    ];
    /** @nocollapse */
    ChartJsComponent.ctorParameters = function () { return [
        { type: MatIconRegistry },
        { type: DomSanitizer }
    ]; };
    ChartJsComponent.propDecorators = {
        type: [{ type: Input }],
        data: [{ type: Input }],
        label: [{ type: Input }],
        updateChart: [{ type: Input }],
        canvasRef: [{ type: ViewChild, args: ['canvas',] }]
    };
    return ChartJsComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChartJsModule = /** @class */ (function () {
    function ChartJsModule() {
    }
    ChartJsModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        MatIconModule
                    ],
                    declarations: [
                        ChartJsComponent
                    ],
                    providers: [],
                    exports: [
                        ChartJsComponent
                    ]
                },] }
    ];
    return ChartJsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ChartJsModule, ChartJsComponent };

//# sourceMappingURL=biosoftcl-chart-js-module.js.map